<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * This page prints a review of a particular quiz attempt
 *
 * It is used either by the student whose attempts this is, after the attempt,
 * or by a teacher reviewing another's attempt during or afterwards.
 *
 * @package   mod_quiz
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */


require_once(__DIR__ . '/../../config.php');
require_once($CFG->dirroot . '/mod/quiz/locallib.php');
require_once($CFG->dirroot . '/mod/quiz/report/reportlib.php');

$attemptid = required_param('attempt', PARAM_INT);
$page      = optional_param('page', 0, PARAM_INT);
$showall   = optional_param('showall', null, PARAM_BOOL);
$cmid      = optional_param('cmid', null, PARAM_INT);

$url = new moodle_url('/mod/quiz/review.php', array('attempt'=>$attemptid));
if ($page !== 0) {
    $url->param('page', $page);
} else if ($showall) {
    $url->param('showall', $showall);
}
$PAGE->set_url($url);

$attemptobj = quiz_create_attempt_handling_errors($attemptid, $cmid);
$page = $attemptobj->force_page_number_into_range($page);

// Now we can validate the params better, re-genrate the page URL.
if ($showall === null) {
    $showall = $page == 0 && $attemptobj->get_default_show_all('review');
}
$PAGE->set_url($attemptobj->review_url(null, $page, $showall));

// Check login.
require_login($attemptobj->get_course(), false, $attemptobj->get_cm());
$attemptobj->check_review_capability();

// Create an object to manage all the other (non-roles) access rules.
$accessmanager = $attemptobj->get_access_manager(time());
$accessmanager->setup_attempt_page($PAGE);

$options = $attemptobj->get_display_options(true);

// Check permissions - warning there is similar code in reviewquestion.php and
// quiz_attempt::check_file_access. If you change on, change them all.
if ($attemptobj->is_own_attempt()) {
    if (!$attemptobj->is_finished()) {
        redirect($attemptobj->attempt_url(null, $page));

    } else if (!$options->attempt) {
        $accessmanager->back_to_view_page($PAGE->get_renderer('mod_quiz'),
                $attemptobj->cannot_review_message());
    }

} else if (!$attemptobj->is_review_allowed()) {
    throw new moodle_quiz_exception($attemptobj->get_quizobj(), 'noreviewattempt');
}

// Load the questions and states needed by this page.
if ($showall) {
    $questionids = $attemptobj->get_slots();
} else {
    $questionids = $attemptobj->get_slots($page);
}

// Save the flag states, if they are being changed.
if ($options->flags == question_display_options::EDITABLE && optional_param('savingflags', false,
        PARAM_BOOL)) {
    require_sesskey();
    $attemptobj->save_question_flags();
    redirect($attemptobj->review_url(null, $page, $showall));
}

// Work out appropriate title and whether blocks should be shown.
if ($attemptobj->is_own_preview()) {
    navigation_node::override_active_url($attemptobj->start_attempt_url());

} else {
    if (empty($attemptobj->get_quiz()->showblocks) && !$attemptobj->is_preview_user()) {
        $PAGE->blocks->show_only_fake_blocks();
    }
}

// Set up the page header.
$headtags = $attemptobj->get_html_head_contributions($page, $showall);
$PAGE->set_title($attemptobj->review_page_title($page, $showall));
$PAGE->set_heading($attemptobj->get_course()->fullname);

// Summary table start. ============================================================================

// Work out some time-related things.
$attempt = $attemptobj->get_attempt();
$quiz = $attemptobj->get_quiz();
$overtime = 0;

if ($attempt->state == quiz_attempt::FINISHED) {
    if ($timetaken = ($attempt->timefinish - $attempt->timestart)) {
        if ($quiz->timelimit && $timetaken > ($quiz->timelimit + 60)) {
            $overtime = $timetaken - $quiz->timelimit;
            $overtime = format_time($overtime);
        }
        $timetaken = format_time($timetaken);
    } else {
        $timetaken = "-";
    }
} else {
    $timetaken = get_string('unfinished', 'quiz');
}

// Prepare summary informat about the whole attempt.
$summarydata = array();
if (!$attemptobj->get_quiz()->showuserpicture && $attemptobj->get_userid() != $USER->id) {
    // If showuserpicture is true, the picture is shown elsewhere, so don't repeat it.
    $student = $DB->get_record('user', array('id' => $attemptobj->get_userid()));
    $userpicture = new user_picture($student);
    $userpicture->courseid = $attemptobj->get_courseid();
    $summarydata['user'] = array(
        'title'   => $userpicture,
        'content' => new action_link(new moodle_url('/user/view.php', array(
                                'id' => $student->id, 'course' => $attemptobj->get_courseid())),
                          fullname($student, true)),
    );
}

if ($attemptobj->has_capability('mod/quiz:viewreports')) {
    $attemptlist = $attemptobj->links_to_other_attempts($attemptobj->review_url(null, $page,
            $showall));
    if ($attemptlist) {
        $summarydata['attemptlist'] = array(
            'title'   => get_string('attempts', 'quiz'),
            'content' => $attemptlist,
        );
    }
}

// Timing information.
$summarydata['startedon'] = array(
    'title'   => get_string('startedon', 'quiz'),
    'content' => userdate($attempt->timestart),
);

$summarydata['state'] = array(
    'title'   => get_string('attemptstate', 'quiz'),
    'content' => quiz_attempt::state_name($attempt->state),
);

if ($attempt->state == quiz_attempt::FINISHED) {
    $summarydata['completedon'] = array(
        'title'   => get_string('completedon', 'quiz'),
        'content' => userdate($attempt->timefinish),
    );
    $summarydata['timetaken'] = array(
        'title'   => get_string('timetaken', 'quiz'),
        'content' => $timetaken,
    );
}

if (!empty($overtime)) {
    $summarydata['overdue'] = array(
        'title'   => get_string('overdue', 'quiz'),
        'content' => $overtime,
    );
}

// Show marks (if the user is allowed to see marks at the moment).
$grade = quiz_rescale_grade($attempt->sumgrades, $quiz, false);
if ($options->marks >= question_display_options::MARK_AND_MAX && quiz_has_grades($quiz)) {

    if ($attempt->state != quiz_attempt::FINISHED) {
        // Cannot display grade.

    } else if (is_null($grade)) {
        $summarydata['grade'] = array(
            'title'   => get_string('grade', 'quiz'),
            'content' => quiz_format_grade($quiz, $grade),
        );

    } else {
        // Show raw marks only if they are different from the grade (like on the view page).
        if ($quiz->grade != $quiz->sumgrades) {
            $a = new stdClass();
            $a->grade = quiz_format_grade($quiz, $attempt->sumgrades);
            $a->maxgrade = quiz_format_grade($quiz, $quiz->sumgrades);
            $summarydata['marks'] = array(
                'title'   => get_string('marks', 'quiz'),
                'content' => get_string('outofshort', 'quiz', $a),
            );
        }

        // Now the scaled grade.
        $a = new stdClass();
        $a->grade = html_writer::tag('b', quiz_format_grade($quiz, $grade));
        $a->maxgrade = quiz_format_grade($quiz, $quiz->grade);
        if ($quiz->grade != 100) {
            $a->percent = html_writer::tag('b', format_float(
                    $attempt->sumgrades * 100 / $quiz->sumgrades, 0));
            $formattedgrade = get_string('outofpercent', 'quiz', $a);
        } else {
            $formattedgrade = get_string('outof', 'quiz', $a);
        }
        $summarydata['grade'] = array(
            'title'   => get_string('grade', 'quiz'),
            'content' => $formattedgrade,
        );
    }
}

// Any additional summary data from the behaviour.
$summarydata = array_merge($summarydata, $attemptobj->get_additional_summary_data($options));



//added by taz for email sending when a user attempt quiz
require_once($CFG->dirroot.'/user/profile/lib.php');

profile_load_data($USER);

/*if($USER->email=='isabelrodriguezsiblesz@gmail.com'){
echo '<pre>';print_r($USER);die();
}*/
/* if($attempt->certificate == 1 && $attempt->percent >= 80){
 redirect($CFG->wwwroot.'/mod/certificate/view.php);
 }  */


//echo $attempt->certificate;
$percents = format_float($attempt->sumgrades * 100 / $quiz->sumgrades, 0);
if($attempt->state == quiz_attempt::FINISHED){
if($attempt->certificate == 0){
if($percents >= 80){
date_default_timezone_set("America/New_York");
$parameters['mvUserid'] = '2Babydrive';
$parameters['mvPassword'] = '3Orange$';
$parameters['mvSchoolid'] = '22847';
//$parameters['mvStartTime'] = '0001';
$parameters['mvClassDate'] = date('mdY',$attempt->timefinish);
$parameters['mvStartTime'] = date('Hi',$attempt->timefinish);
$parameters['mvSchoolIns'] = '60237';
$parameters['mvSchoolCourse'] = '30749';
$parameters['mvFirstName'] = $USER->firstname;
$parameters['mvMiddleName'] = $USER->middlename;
$parameters['mvLastName'] = $USER->lastname;
$parameters['mvDob'] = date('mdY',$USER->profile['dateofbirth']);
if($USER->profile['Gender'] == 'Male'){
$gender = 'M';
}else{
$gender = 'F';
}
if($USER->profile['reasonforattending'] == "To get my driver's permit / license"){
$reasonforattending = 'T1';
}else{
$reasonforattending = 'T2';
}
$parameters['mvSex'] = $gender;
$parameters['mvSocialSN'] = $USER->profile_field_IDnumber;
$parameters['mvReasonAttending'] = $reasonforattending;
$parameters['mvDriversLicense'] = 'none';
$parameters['mvEmail'] = $USER->email; 

$opts = array(
        'http'=>array(
            'user_agent' => 'PHPSoapClient'
            )
        );
$context = stream_context_create($opts);
ini_set('default_socket_timeout',200);
  $client=new SoapClient("https://services.flhsmv.gov/DriverSchoolWebService/wsPrimerComponentService.svc?singleWsdl");  
//$client=new SoapClient("https://services.flhsmv.gov/DriverSchoolWebService/wsPrimerComponentService.svc?wsdl");  
$result = $client->wsVerifyData($parameters);
//echo '<pre>';
//print_r($parameters);
//print_r($result);die();
if (is_soap_fault($result)) {
    trigger_error("SOAP Fault: (faultcode: {$result->faultcode}, faultstring: {$result->faultstring})", E_USER_ERROR);
}

$msg = ''; 
//$to = "$USER->email";
$from = "$12 Florida Driver";
$eol = PHP_EOL;
$subject = "Your Florida Confirmation Number - take it to the DMV";
$msg ="Dear $USER->firstname\n" . "</br>" . "</br>" ;
$msg .= " Congratulations for passing Traffic Law and Substance Abuse Education! Take this confirmation number to the DMV." . "<br>" . "<br>";
$msg .= "Your certificate number is $result->wsVerifyDataResult\n" . "<br>" . "<br>";
$msg .= "If the number above is BD000, that means you made an error when you created your profile. Email us at CustomerCare@12DollarFloridaDriver.com and we will take care of it.";
// $msg .= "Your certificate number is $result->wsVerifyDataResponse\n" . "<br>" . "<br>";
$msg .= "Next step: Click on the link in the menu tab that says Permit Checklist, and it is all explained there. Basically, you will click on the Driver's Manual, study it on your own, and then go to the DMV and take the Knowledge Exam, and they will guide you from there." . "<br>";
$headers  = "From: ".$from.$eol;
$headers .= "MIME-Version: 1.0" . $eol;
$headers .= "Content-type:text/html;charset=UTF-8" . $eol;
mail($to,$subject,$msg, $headers); 
$DB->set_field('quiz_attempts', 'certificate', 1, array('id' => $attemptid));
$DB->set_field('quiz_attempts', 'percent', $percents, array('id' => $attemptid));

//Added by Desmond on 26Jan2021
$usercertData=new stdClass();
$usercertData->userid = $USER->id;
$usercertData->fieldid = 71;
$usercertData->data = $result->wsVerifyDataResult;
$DB->insert_record('user_info_data', $usercertData); 
//End addition by Desmond 26Jan2021

/*$DB->insert_record('user_info_data', array('userid' => $USER->id,
                    'fieldid' => '71', 'data' => $result->wsVerifyDataResult)); */
                    
                    
//$DB->set_field('quiz_attempts', 'certid', $result->wsVerifyDataResult, array('id' => $attemptid));
//$DB->insert_record('user_info_data', 'certid', $result->wsVerifyDataResult, array('id' => $attemptid));
//$DB->update_record('user_info_field', 'certid', $result->wsVerifyDataResult, array('id' => $attemptid));
}
}
}
//end added by taz for email sending when a user attempt quiz










// Feedback if there is any, and the user is allowed to see it now.
$feedback = $attemptobj->get_overall_feedback($grade);
if ($options->overallfeedback && $feedback) {
    $summarydata['feedback'] = array(
        'title'   => get_string('feedback', 'quiz'),
        'content' => $feedback,
    );
}

// Summary table end. ==============================================================================

if ($showall) {
    $slots = $attemptobj->get_slots();
    $lastpage = true;
} else {
    $slots = $attemptobj->get_slots($page);
    $lastpage = $attemptobj->is_last_page($page);
}

$output = $PAGE->get_renderer('mod_quiz');

// Arrange for the navigation to be displayed.
/*$navbc = $attemptobj->get_navigation_panel($output, 'quiz_review_nav_panel', $page, $showall);
$regions = $PAGE->blocks->get_regions();
$PAGE->blocks->add_fake_block($navbc, reset($regions));  */

echo $output->review_page($attemptobj, $slots, $page, $showall, $lastpage, $options, $summarydata);

// Trigger an event for this review.
$attemptobj->fire_attempt_reviewed_event();
